'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var pdas = require('./pdas.cjs');
var Bid = require('./Bid.cjs');
var accounts = require('./accounts.cjs');
var Operation = require('../../types/Operation.cjs');

// Operation
// -----------------

const Key = 'FindBidByAddressOperation';
const findBidByAddressOperation = Operation.useOperation(Key);
// -----------------
// Handler
// -----------------
const findBidByAddressOperationHandler = {
  handle: async (operation, metaplex, scope) => {
    const {
      address,
      auctionHouse,
      commitment,
      loadJsonMetadata = true
    } = operation.input;
    const receiptAddress = pdas.findBidReceiptPda(address);
    const account = accounts.toBidReceiptAccount(await metaplex.rpc().getAccount(receiptAddress, commitment));
    scope.throwIfCanceled();
    const lazyBid = Bid.toLazyBid(account, auctionHouse);
    return metaplex.auctions().for(auctionHouse).loadBid(lazyBid, {
      loadJsonMetadata,
      commitment
    }).run(scope);
  }
};

exports.findBidByAddressOperation = findBidByAddressOperation;
exports.findBidByAddressOperationHandler = findBidByAddressOperationHandler;
//# sourceMappingURL=findBidByAddress.cjs.map
