'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var accounts = require('./accounts.cjs');
var errors = require('./errors.cjs');
var Mint = require('./Mint.cjs');
var pdas = require('./pdas.cjs');
var Token = require('./Token.cjs');
var Operation = require('../../types/Operation.cjs');

// -----------------
// Clients
// -----------------

/** @internal */
function _findTokenWithMintByMintClient(input) {
  return this.metaplex.operations().getTask(findTokenWithMintByMintOperation(input));
} // -----------------
// Operation
// -----------------

const Key = 'FindTokenWithMintByMintOperation';
const findTokenWithMintByMintOperation = Operation.useOperation(Key);
// -----------------
// Handler
// -----------------
const findTokenWithMintByMintOperationHandler = {
  handle: async (operation, metaplex) => {
    const {
      mint,
      address,
      addressType,
      commitment
    } = operation.input;
    const tokenAddress = addressType === 'owner' ? pdas.findAssociatedTokenAccountPda(mint, address) : address;
    const accounts$1 = await metaplex.rpc().getMultipleAccounts([mint, tokenAddress], commitment);
    const mintAccount = accounts.toMintAccount(accounts$1[0]);
    const tokenAccount = accounts.toTokenAccount(accounts$1[1]);

    if (!tokenAccount.data.mint.equals(mint)) {
      throw new errors.TokenAndMintDoNotMatchError(tokenAddress, tokenAccount.data.mint, mint);
    }

    return Token.toTokenWithMint(tokenAccount, Mint.toMint(mintAccount));
  }
};

exports._findTokenWithMintByMintClient = _findTokenWithMintByMintClient;
exports.findTokenWithMintByMintOperation = findTokenWithMintByMintOperation;
exports.findTokenWithMintByMintOperationHandler = findTokenWithMintByMintOperationHandler;
//# sourceMappingURL=findTokenWithMintByMint.cjs.map
