'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var splToken = require('@solana/spl-token');
var pdas = require('./pdas.cjs');
var program = require('./program.cjs');
var Operation = require('../../types/Operation.cjs');
var Signer = require('../../types/Signer.cjs');
var TransactionBuilder = require('../../utils/TransactionBuilder.cjs');

// -----------------
// Clients
// -----------------

/** @internal */
function _thawTokensClient(input) {
  return this.metaplex.operations().getTask(thawTokensOperation(input));
}
/** @internal */

function _thawTokensBuildersClient(input) {
  return thawTokensBuilder(this.metaplex, input);
} // -----------------
// Operation
// -----------------

const Key = 'ThawTokensOperation';
const thawTokensOperation = Operation.useOperation(Key);
// -----------------
// Handler
// -----------------
const thawTokensOperationHandler = {
  async handle(operation, metaplex) {
    return thawTokensBuilder(metaplex, operation.input).sendAndConfirm(metaplex, operation.input.confirmOptions);
  }

}; // -----------------
// Builder
// -----------------

const thawTokensBuilder = (metaplex, params) => {
  var _params$instructionKe;

  const {
    mintAddress,
    tokenOwner = metaplex.identity().publicKey,
    tokenAddress,
    multiSigners = [],
    freezeAuthority,
    tokenProgram = program.TokenProgram.publicKey
  } = params;
  const [authorityPublicKey, signers] = Signer.isSigner(freezeAuthority) ? [freezeAuthority.publicKey, [freezeAuthority]] : [freezeAuthority, multiSigners];
  const tokenAddressOrAta = tokenAddress !== null && tokenAddress !== void 0 ? tokenAddress : pdas.findAssociatedTokenAccountPda(mintAddress, tokenOwner);
  return TransactionBuilder.TransactionBuilder.make().add({
    instruction: splToken.createThawAccountInstruction(tokenAddressOrAta, mintAddress, authorityPublicKey, multiSigners, tokenProgram),
    signers,
    key: (_params$instructionKe = params.instructionKey) !== null && _params$instructionKe !== void 0 ? _params$instructionKe : 'thawTokens'
  });
};

exports._thawTokensBuildersClient = _thawTokensBuildersClient;
exports._thawTokensClient = _thawTokensClient;
exports.thawTokensBuilder = thawTokensBuilder;
exports.thawTokensOperation = thawTokensOperation;
exports.thawTokensOperationHandler = thawTokensOperationHandler;
//# sourceMappingURL=thawTokens.cjs.map
