import { useOperation } from '../../types/Operation.mjs';
import { assertNftOrSftWithToken } from '../nftModule/Nft.mjs';
import { amount } from '../../types/Amount.mjs';

// Operation
// -----------------

const Key = 'LoadPurchaseOperation';
const loadPurchaseOperation = useOperation(Key);
// -----------------
// Handler
// -----------------
const loadPurchaseOperationHandler = {
  handle: async (operation, metaplex, scope) => {
    const {
      lazyPurchase,
      loadJsonMetadata = true,
      commitment
    } = operation.input;
    const asset = await metaplex.nfts().findByMetadata(lazyPurchase.metadataAddress, {
      tokenOwner: lazyPurchase.buyerAddress,
      commitment,
      loadJsonMetadata
    }).run(scope);
    assertNftOrSftWithToken(asset);
    return { ...lazyPurchase,
      lazy: false,
      isPublic: false,
      asset,
      tokens: amount(lazyPurchase.tokens, asset.mint.currency)
    };
  }
};

export { loadPurchaseOperation, loadPurchaseOperationHandler };
//# sourceMappingURL=loadPurchase.mjs.map
