import { TokenMetadataProgram } from './program.mjs';
import { findNftsByMintListOperation } from './findNftsByMintList.mjs';
import { useOperation } from '../../types/Operation.mjs';

// -----------------
// Clients
// -----------------

/** @internal */
function _findNftsByCreatorsClient(creator, options) {
  return this.metaplex.operations().getTask(findNftsByCreatorOperation({
    creator,
    ...options
  }));
} // -----------------
// Operation
// -----------------

const Key = 'FindNftsByCreatorOperation';
const findNftsByCreatorOperation = useOperation(Key);
// -----------------
// Handler
// -----------------
const findNftsByCreatorOperationHandler = {
  handle: async (operation, metaplex, scope) => {
    const {
      creator,
      position = 1,
      commitment
    } = operation.input;
    const mints = await TokenMetadataProgram.metadataV1Accounts(metaplex).selectMint().whereCreator(position, creator).getDataAsPublicKeys();
    scope.throwIfCanceled();
    const nfts = await metaplex.operations().execute(findNftsByMintListOperation({
      mints,
      commitment
    }), scope);
    scope.throwIfCanceled();
    return nfts.filter(nft => nft !== null);
  }
};

export { _findNftsByCreatorsClient, findNftsByCreatorOperation, findNftsByCreatorOperationHandler };
//# sourceMappingURL=findNftsByCreator.mjs.map
