import { toMetadataAccount } from './accounts.mjs';
import { findMetadataPda } from './pdas.mjs';
import { toMetadata } from './Metadata.mjs';
import { GmaBuilder } from '../../utils/GmaBuilder.mjs';
import { useOperation } from '../../types/Operation.mjs';

// -----------------
// Clients
// -----------------

/** @internal */
function _findNftsByMintListClient(mints, options) {
  return this.metaplex.operations().getTask(findNftsByMintListOperation({
    mints,
    ...options
  }));
} // -----------------
// Operation
// -----------------

const Key = 'FindNftsByMintListOperation';
const findNftsByMintListOperation = useOperation(Key);
// -----------------
// Handler
// -----------------
const findNftsByMintListOperationHandler = {
  handle: async (operation, metaplex, scope) => {
    const {
      mints,
      commitment
    } = operation.input;
    const metadataPdas = mints.map(mint => findMetadataPda(mint));
    const metadataInfos = await GmaBuilder.make(metaplex, metadataPdas, {
      commitment
    }).get();
    scope.throwIfCanceled();
    return metadataInfos.map(account => {
      if (!account.exists) {
        return null;
      }

      try {
        return toMetadata(toMetadataAccount(account));
      } catch (error) {
        return null;
      }
    });
  }
};

export { _findNftsByMintListClient, findNftsByMintListOperation, findNftsByMintListOperationHandler };
//# sourceMappingURL=findNftsByMintList.mjs.map
