import { findNftsByMintListOperation } from './findNftsByMintList.mjs';
import { useOperation } from '../../types/Operation.mjs';
import { TokenProgram } from '../tokenModule/program.mjs';

// -----------------
// Clients
// -----------------

/** @internal */
function _findNftsByOwnerClient(owner, options) {
  return this.metaplex.operations().getTask(findNftsByOwnerOperation({
    owner,
    ...options
  }));
} // -----------------
// Operation
// -----------------

const Key = 'FindNftsByOwnerOperation';
const findNftsByOwnerOperation = useOperation(Key);
// -----------------
// Handler
// -----------------
const findNftsByOwnerOperationHandler = {
  handle: async (operation, metaplex, scope) => {
    const {
      owner,
      commitment
    } = operation.input;
    const mints = await TokenProgram.tokenAccounts(metaplex).selectMint().whereOwner(owner).whereAmount(1).getDataAsPublicKeys();
    scope.throwIfCanceled();
    const nfts = await metaplex.operations().execute(findNftsByMintListOperation({
      mints,
      commitment
    }), scope);
    scope.throwIfCanceled();
    return nfts.filter(nft => nft !== null);
  }
};

export { _findNftsByOwnerClient, findNftsByOwnerOperation, findNftsByOwnerOperationHandler };
//# sourceMappingURL=findNftsByOwner.mjs.map
