import { TokenMetadataProgram } from './program.mjs';
import { findNftsByMintListOperation } from './findNftsByMintList.mjs';
import { useOperation } from '../../types/Operation.mjs';

// -----------------
// Clients
// -----------------

/** @internal */
function _findNftsByUpdateAuthorityClient(updateAuthority, options) {
  return this.metaplex.operations().getTask(findNftsByUpdateAuthorityOperation({
    updateAuthority,
    ...options
  }));
} // -----------------
// Operation
// -----------------

const Key = 'FindNftsByUpdateAuthorityOperation';
const findNftsByUpdateAuthorityOperation = useOperation(Key);
// -----------------
// Handler
// -----------------
const findNftsByUpdateAuthorityOperationHandler = {
  handle: async (operation, metaplex, scope) => {
    const {
      updateAuthority,
      commitment
    } = operation.input;
    const mints = await TokenMetadataProgram.metadataV1Accounts(metaplex).selectMint().whereUpdateAuthority(updateAuthority).getDataAsPublicKeys();
    scope.throwIfCanceled();
    const nfts = await metaplex.operations().execute(findNftsByMintListOperation({
      mints,
      commitment
    }), scope);
    scope.throwIfCanceled();
    return nfts.filter(nft => nft !== null);
  }
};

export { _findNftsByUpdateAuthorityClient, findNftsByUpdateAuthorityOperation, findNftsByUpdateAuthorityOperationHandler };
//# sourceMappingURL=findNftsByUpdateAuthority.mjs.map
