import { createThawDelegatedAccountInstruction } from '@metaplex-foundation/mpl-token-metadata';
import { toMintAddress } from './helpers.mjs';
import { findMasterEditionV2Pda } from './pdas.mjs';
import { useOperation } from '../../types/Operation.mjs';
import { TokenProgram } from '../tokenModule/program.mjs';
import { findAssociatedTokenAccountPda } from '../tokenModule/pdas.mjs';
import { TransactionBuilder } from '../../utils/TransactionBuilder.mjs';

// Clients
// -----------------

/** @internal */

function _thawDelegatedNftClient(nft, input) {
  return this.metaplex.operations().getTask(thawDelegatedNftOperation({ ...input,
    mintAddress: toMintAddress(nft)
  }));
}
/** @internal */

function _thawDelegatedNftBuildersClient(input) {
  return thawDelegatedNftBuilder(this.metaplex, input);
} // -----------------
// Operation
// -----------------

const Key = 'ThawDelegatedNftOperation';
const thawDelegatedNftOperation = useOperation(Key);
// -----------------
// Handler
// -----------------
const thawDelegatedNftOperationHandler = {
  async handle(operation, metaplex) {
    return thawDelegatedNftBuilder(metaplex, operation.input).sendAndConfirm(metaplex, operation.input.confirmOptions);
  }

}; // -----------------
// Builder
// -----------------

const thawDelegatedNftBuilder = (metaplex, params) => {
  var _params$instructionKe;

  const {
    mintAddress,
    delegateAuthority,
    tokenOwner = metaplex.identity().publicKey,
    tokenAddress,
    tokenProgram = TokenProgram.publicKey
  } = params;
  const editionAddress = findMasterEditionV2Pda(mintAddress);
  const tokenAddressOrAta = tokenAddress !== null && tokenAddress !== void 0 ? tokenAddress : findAssociatedTokenAccountPda(mintAddress, tokenOwner);
  return TransactionBuilder.make().add({
    instruction: createThawDelegatedAccountInstruction({
      delegate: delegateAuthority.publicKey,
      tokenAccount: tokenAddressOrAta,
      edition: editionAddress,
      mint: mintAddress,
      tokenProgram
    }),
    signers: [delegateAuthority],
    key: (_params$instructionKe = params.instructionKey) !== null && _params$instructionKe !== void 0 ? _params$instructionKe : 'thawDelegatedNft'
  });
};

export { _thawDelegatedNftBuildersClient, _thawDelegatedNftClient, thawDelegatedNftBuilder, thawDelegatedNftOperation, thawDelegatedNftOperationHandler };
//# sourceMappingURL=thawDelegatedNft.mjs.map
