import { toTokenAccount, toMintAccount } from './accounts.mjs';
import { toMint } from './Mint.mjs';
import { toTokenWithMint } from './Token.mjs';
import { useOperation } from '../../types/Operation.mjs';

// -----------------
// Clients
// -----------------

/** @internal */
function _findTokenWithMintByAddressClient(address, options) {
  return this.metaplex.operations().getTask(findTokenWithMintByAddressOperation({
    address,
    ...options
  }));
} // -----------------
// Operation
// -----------------

const Key = 'FindTokenWithMintByAddressOperation';
const findTokenWithMintByAddressOperation = useOperation(Key);
// -----------------
// Handler
// -----------------
const findTokenWithMintByAddressOperationHandler = {
  handle: async (operation, metaplex) => {
    const {
      address,
      commitment
    } = operation.input;
    const tokenAccount = toTokenAccount(await metaplex.rpc().getAccount(address, commitment));
    const mintAccount = toMintAccount(await metaplex.rpc().getAccount(tokenAccount.data.mint, commitment));
    return toTokenWithMint(tokenAccount, toMint(mintAccount));
  }
};

export { _findTokenWithMintByAddressClient, findTokenWithMintByAddressOperation, findTokenWithMintByAddressOperationHandler };
//# sourceMappingURL=findTokenWithMintByAddress.mjs.map
