import type { PublicKey } from '@solana/web3.js';
import type { Metaplex } from '../../Metaplex';
import { CandyMachinesBuildersClient } from './CandyMachinesBuildersClient';
import { NftWithToken } from '../nftModule';
import { Task } from '../../utils';
import { CandyMachine } from './CandyMachine';
import { CreateCandyMachineInput, CreateCandyMachineInputWithoutConfigs, CreateCandyMachineOutput } from './createCandyMachine';
import { CandyMachineJsonConfigs } from './CandyMachineJsonConfigs';
import { FindCandyMachineByAddressInput } from './findCandyMachineByAddress';
import { FindCandyMachinesByPublicKeyFieldInput } from './findCandyMachinesByPublicKeyField';
import { FindMintedNftsByCandyMachineInput, FindMintedNftsByCandyMachineOutput } from './findMintedNftsByCandyMachine';
import { InsertItemsToCandyMachineInput, InsertItemsToCandyMachineOutput } from './insertItemsToCandyMachine';
import { UpdateCandyMachineInput, UpdateCandyMachineInputWithoutConfigs, UpdateCandyMachineOutput } from './updateCandyMachine';
import { MintCandyMachineInput, MintCandyMachineOutput } from './mintCandyMachine';
import { DeleteCandyMachineInput, DeleteCandyMachineOutput } from './deleteCandyMachine';
export declare class CandyMachinesClient {
    readonly metaplex: Metaplex;
    constructor(metaplex: Metaplex);
    builders(): CandyMachinesBuildersClient;
    create(input: CreateCandyMachineInput): Task<CreateCandyMachineOutput & {
        candyMachine: CandyMachine;
    }>;
    createFromJsonConfig(input: CreateCandyMachineInputWithoutConfigs & {
        json: CandyMachineJsonConfigs;
    }): Task<CreateCandyMachineOutput & {
        candyMachine: Readonly<{
            model: "candyMachine";
            address: PublicKey;
            programAddress: PublicKey;
            version: 1 | 2;
            authorityAddress: PublicKey;
            walletAddress: PublicKey;
            tokenMintAddress: import("../../utils").Option<PublicKey>;
            collectionMintAddress: import("../../utils").Option<PublicKey>;
            uuid: string;
            price: import("../../types").Amount<import("../../types").Currency>;
            symbol: string;
            sellerFeeBasisPoints: number;
            isMutable: boolean;
            retainAuthority: boolean;
            goLiveDate: import("../../utils").Option<import("../../types").DateTime>;
            maxEditionSupply: import("../../types").BigNumber;
            items: Readonly<{
                name: string;
                uri: string;
            }>[];
            itemsAvailable: import("../../types").BigNumber;
            itemsMinted: import("../../types").BigNumber;
            itemsRemaining: import("../../types").BigNumber;
            itemsLoaded: import("../../types").BigNumber;
            isFullyLoaded: boolean;
            endSettings: import("../../utils").Option<import("./CandyMachine").EndSettings>;
            hiddenSettings: import("../../utils").Option<import("./CandyMachine").HiddenSettings>;
            whitelistMintSettings: import("../../utils").Option<import("./CandyMachine").WhitelistMintSettings>;
            gatekeeper: import("../../utils").Option<import("./CandyMachine").Gatekeeper>;
            creators: Readonly<{
                address: PublicKey;
                verified: boolean;
                share: number;
            }>[];
        }>;
    }, []>;
    delete(candyMachine: CandyMachine, options?: Omit<DeleteCandyMachineInput, 'candyMachine'>): Task<DeleteCandyMachineOutput>;
    findAllByWallet(wallet: PublicKey, options?: Omit<FindCandyMachinesByPublicKeyFieldInput, 'type' | 'publicKey'>): Task<CandyMachine[]>;
    findAllByAuthority(authority: PublicKey, options?: Omit<FindCandyMachinesByPublicKeyFieldInput, 'type' | 'publicKey'>): Task<CandyMachine[]>;
    findByAddress(address: PublicKey, options?: Omit<FindCandyMachineByAddressInput, 'address'>): Task<CandyMachine>;
    findMintedNfts(candyMachine: PublicKey, options?: Omit<FindMintedNftsByCandyMachineInput, 'candyMachine'>): Task<FindMintedNftsByCandyMachineOutput>;
    insertItems(candyMachine: CandyMachine, input: Omit<InsertItemsToCandyMachineInput, 'candyMachine'>): Task<InsertItemsToCandyMachineOutput>;
    mint(candyMachine: CandyMachine, input?: Omit<MintCandyMachineInput, 'candyMachine'>): Task<MintCandyMachineOutput & {
        nft: NftWithToken;
    }>;
    refresh(candyMachine: CandyMachine | PublicKey, options?: Omit<FindCandyMachineByAddressInput, 'address'>): Task<CandyMachine>;
    update(candyMachine: CandyMachine, input: Omit<UpdateCandyMachineInput, 'candyMachine'>): Task<UpdateCandyMachineOutput>;
    updateFromJsonConfig(candyMachine: CandyMachine, input: Omit<UpdateCandyMachineInputWithoutConfigs, 'candyMachine'> & {
        json: CandyMachineJsonConfigs;
    }): Task<UpdateCandyMachineOutput, []>;
}
