import { Metaplex } from '../../Metaplex';
import { BigNumber, CreatorInput, Operation, OperationHandler, Signer, SplTokenAmount } from '../../types';
import { Option, TransactionBuilder } from '../../utils';
import { Uses } from '@metaplex-foundation/mpl-token-metadata';
import { ConfirmOptions, PublicKey } from '@solana/web3.js';
import { SendAndConfirmTransactionResponse } from '../rpcModule';
declare const Key: "CreateSftOperation";
export declare const createSftOperation: import("../../types").OperationConstructor<CreateSftOperation, "CreateSftOperation", CreateSftInput, CreateSftOutput>;
export declare type CreateSftOperation = Operation<typeof Key, CreateSftInput, CreateSftOutput>;
export interface CreateSftInput {
    payer?: Signer;
    updateAuthority?: Signer;
    mintAuthority?: Signer;
    freezeAuthority?: Option<PublicKey>;
    useNewMint?: Signer;
    useExistingMint?: PublicKey;
    tokenAddress?: PublicKey | Signer;
    tokenOwner?: PublicKey;
    tokenAmount?: SplTokenAmount;
    decimals?: number;
    uri: string;
    name: string;
    sellerFeeBasisPoints: number;
    symbol?: string;
    creators?: CreatorInput[];
    isMutable?: boolean;
    maxSupply?: Option<BigNumber>;
    uses?: Option<Uses>;
    isCollection?: boolean;
    collection?: Option<PublicKey>;
    collectionAuthority?: Option<Signer>;
    collectionAuthorityIsDelegated?: boolean;
    collectionIsSized?: boolean;
    tokenProgram?: PublicKey;
    associatedTokenProgram?: PublicKey;
    confirmOptions?: ConfirmOptions;
}
export interface CreateSftOutput {
    response: SendAndConfirmTransactionResponse;
    mintAddress: PublicKey;
    metadataAddress: PublicKey;
    tokenAddress: PublicKey | null;
}
export declare const createSftOperationHandler: OperationHandler<CreateSftOperation>;
export declare type CreateSftBuilderParams = Omit<CreateSftInput, 'confirmOptions'> & {
    createMintAccountInstructionKey?: string;
    initializeMintInstructionKey?: string;
    createAssociatedTokenAccountInstructionKey?: string;
    createTokenAccountInstructionKey?: string;
    initializeTokenInstructionKey?: string;
    mintTokensInstructionKey?: string;
    createMetadataInstructionKey?: string;
};
export declare type CreateSftBuilderContext = Omit<CreateSftOutput, 'response'>;
export declare const createSftBuilder: (metaplex: Metaplex, params: CreateSftBuilderParams) => Promise<TransactionBuilder<CreateSftBuilderContext>>;
export {};
