import { ConfirmOptions, PublicKey } from '@solana/web3.js';
import type { Metaplex } from '../../Metaplex';
import { KeypairSigner, Operation, OperationHandler, Signer, SplTokenAmount } from '../../types';
import { TransactionBuilder } from '../../utils';
import { SendAndConfirmTransactionResponse } from '../rpcModule';
import { Mint } from './Mint';
declare const Key: "MintTokensOperation";
export declare const mintTokensOperation: import("../../types").OperationConstructor<MintTokensOperation, "MintTokensOperation", MintTokensInput, MintTokensOutput>;
export declare type MintTokensOperation = Operation<typeof Key, MintTokensInput, MintTokensOutput>;
export declare type MintTokensInput = {
    mint: PublicKey | Mint;
    amount: SplTokenAmount;
    toOwner?: PublicKey;
    toToken?: PublicKey | Signer;
    mintAuthority?: PublicKey | Signer;
    multiSigners?: KeypairSigner[];
    payer?: Signer;
    tokenProgram?: PublicKey;
    associatedTokenProgram?: PublicKey;
    confirmOptions?: ConfirmOptions;
};
export declare type MintTokensOutput = {
    response: SendAndConfirmTransactionResponse;
};
export declare const mintTokensOperationHandler: OperationHandler<MintTokensOperation>;
export declare type MintTokensBuilderParams = Omit<MintTokensInput, 'confirmOptions'> & {
    toTokenExists?: boolean;
    createAssociatedTokenAccountInstructionKey?: string;
    createAccountInstructionKey?: string;
    initializeTokenInstructionKey?: string;
    mintTokensInstructionKey?: string;
};
export declare const mintTokensBuilder: (metaplex: Metaplex, params: MintTokensBuilderParams) => Promise<TransactionBuilder>;
export {};
