import type { Metaplex } from '../../Metaplex';
import { KeypairSigner, Operation, OperationHandler, Signer, SplTokenAmount } from '../../types';
import { TransactionBuilder } from '../../utils';
import { ConfirmOptions, PublicKey } from '@solana/web3.js';
import { SendAndConfirmTransactionResponse } from '../rpcModule';
import { Mint } from './Mint';
declare const Key: "SendTokensOperation";
export declare const sendTokensOperation: import("../../types").OperationConstructor<SendTokensOperation, "SendTokensOperation", SendTokensInput, SendTokensOutput>;
export declare type SendTokensOperation = Operation<typeof Key, SendTokensInput, SendTokensOutput>;
export declare type SendTokensInput = {
    mint: PublicKey | Mint;
    amount: SplTokenAmount;
    toOwner?: PublicKey;
    toToken?: PublicKey | Signer;
    fromOwner?: PublicKey | Signer;
    fromToken?: PublicKey;
    fromMultiSigners?: KeypairSigner[];
    delegateAuthority?: Signer;
    payer?: Signer;
    tokenProgram?: PublicKey;
    associatedTokenProgram?: PublicKey;
    confirmOptions?: ConfirmOptions;
};
export declare type SendTokensOutput = {
    response: SendAndConfirmTransactionResponse;
};
export declare const sendTokensOperationHandler: OperationHandler<SendTokensOperation>;
export declare type SendTokensBuilderParams = Omit<SendTokensInput, 'confirmOptions'> & {
    toTokenExists?: boolean;
    createAssociatedTokenAccountInstructionKey?: string;
    createAccountInstructionKey?: string;
    initializeTokenInstructionKey?: string;
    transferTokensInstructionKey?: string;
};
export declare const sendTokensBuilder: (metaplex: Metaplex, params: SendTokensBuilderParams) => Promise<TransactionBuilder>;
export {};
